@@ -7,13 +7,16 @@
 #include "searchpresetmodel.h"
 
 #include "knewstuffquick_debug.h"
+
 #include <KLocalizedString>
 
+#include "../core/enginebase_p.h"
+
 SearchPresetModel::SearchPresetModel(KNSCore::EngineBase *engine)
     : QAbstractListModel(engine)
     , m_engine(engine)
 {
-    connect(m_engine, &KNSCore::EngineBase::signalSearchPresetsLoaded, this, [this]() {
+    connect(m_engine, qOverload<const QList<KNSCore::SearchPreset> &>(&KNSCore::EngineBase::signalSearchPresetsLoaded), this, [this]() {
         beginResetModel();
         endResetModel();
     });
@@ -30,66 +33,70 @@ QHash<int, QByteArray> SearchPresetModel::roleNames() const
 QVariant SearchPresetModel::data(const QModelIndex &index, int role) const
 {
     if (index.isValid() && checkIndex(index)) {
-        const QList<KNSCore::Provider::SearchPreset> presets = m_engine->searchPresets();
-        const KNSCore::Provider::SearchPreset preset = presets[index.row()];
+        const QList<KNSCore::SearchPreset> presets = m_engine->d->searchPresets;
+        const KNSCore::SearchPreset &preset = presets[index.row()];
 
         if (role == DisplayNameRole) {
-            if (QString name = preset.displayName; !name.isEmpty()) {
+            if (QString name = preset.displayName(); !name.isEmpty()) {
                 return name;
             }
 
-            switch (preset.type) {
-            case KNSCore::Provider::SearchPresetTypes::GoBack:
+            switch (preset.type()) {
+            case KNSCore::SearchPreset::Type::GoBack:
                 return i18nc("Knewstuff5", "Back");
-            case KNSCore::Provider::SearchPresetTypes::Popular:
+            case KNSCore::SearchPreset::Type::Popular:
                 return i18nc("Knewstuff5", "Popular");
-            case KNSCore::Provider::SearchPresetTypes::Featured:
+            case KNSCore::SearchPreset::Type::Featured:
                 return i18nc("Knewstuff5", "Featured");
-            case KNSCore::Provider::SearchPresetTypes::Start:
+            case KNSCore::SearchPreset::Type::Start:
                 return i18nc("Knewstuff5", "Restart");
-            case KNSCore::Provider::SearchPresetTypes::New:
+            case KNSCore::SearchPreset::Type::New:
                 return i18nc("Knewstuff5", "New");
-            case KNSCore::Provider::SearchPresetTypes::Root:
+            case KNSCore::SearchPreset::Type::Root:
                 return i18nc("Knewstuff5", "Home");
-            case KNSCore::Provider::SearchPresetTypes::Shelf:
+            case KNSCore::SearchPreset::Type::Shelf:
                 return i18nc("Knewstuff5", "Shelf");
-            case KNSCore::Provider::SearchPresetTypes::FolderUp:
+            case KNSCore::SearchPreset::Type::FolderUp:
                 return i18nc("Knewstuff5", "Up");
-            case KNSCore::Provider::SearchPresetTypes::Recommended:
+            case KNSCore::SearchPreset::Type::Recommended:
                 return i18nc("Knewstuff5", "Recommended");
-            case KNSCore::Provider::SearchPresetTypes::Subscription:
+            case KNSCore::SearchPreset::Type::Subscription:
                 return i18nc("Knewstuff5", "Subscriptions");
-            case KNSCore::Provider::SearchPresetTypes::AllEntries:
+            case KNSCore::SearchPreset::Type::AllEntries:
                 return i18nc("Knewstuff5", "All Entries");
-            default:
-                return i18nc("Knewstuff5", "Search Preset: %1", preset.request.searchTerm);
+            case KNSCore::SearchPreset::Type::NoPresetType:
+                break;
             }
-        } else if (role == IconRole) {
-            if (QString name = preset.iconName; !name.isEmpty()) {
+            return i18nc("Knewstuff5", "Search Preset: %1", preset.request().searchTerm());
+        }
+        if (role == IconRole) {
+            if (QString name = preset.iconName(); !name.isEmpty()) {
                 return name;
             }
 
-            switch (preset.type) {
-            case KNSCore::Provider::SearchPresetTypes::GoBack:
+            switch (preset.type()) {
+            case KNSCore::SearchPreset::Type::GoBack:
                 return QStringLiteral("arrow-left");
-            case KNSCore::Provider::SearchPresetTypes::Popular:
-            case KNSCore::Provider::SearchPresetTypes::Featured:
-            case KNSCore::Provider::SearchPresetTypes::Recommended:
+            case KNSCore::SearchPreset::Type::Popular:
+            case KNSCore::SearchPreset::Type::Featured:
+            case KNSCore::SearchPreset::Type::Recommended:
                 return QStringLiteral("rating");
-            case KNSCore::Provider::SearchPresetTypes::New:
+            case KNSCore::SearchPreset::Type::New:
                 return QStringLiteral("change-date-symbolic");
-            case KNSCore::Provider::SearchPresetTypes::Start:
+            case KNSCore::SearchPreset::Type::Start:
                 return QStringLiteral("start-over");
-            case KNSCore::Provider::SearchPresetTypes::Root:
+            case KNSCore::SearchPreset::Type::Root:
                 return QStringLiteral("go-home");
-            case KNSCore::Provider::SearchPresetTypes::Shelf:
-            case KNSCore::Provider::SearchPresetTypes::Subscription:
+            case KNSCore::SearchPreset::Type::Shelf:
+            case KNSCore::SearchPreset::Type::Subscription:
                 return QStringLiteral("bookmark");
-            case KNSCore::Provider::SearchPresetTypes::FolderUp:
+            case KNSCore::SearchPreset::Type::FolderUp:
                 return QStringLiteral("arrow-up");
-            default:
-                return QStringLiteral("search");
+            case KNSCore::SearchPreset::Type::AllEntries:
+            case KNSCore::SearchPreset::Type::NoPresetType:
+                break;
             }
+            return QStringLiteral("search");
         }
     }
     return QVariant();
@@ -100,7 +107,7 @@ int SearchPresetModel::rowCount(const QModelIndex &parent) const
     if (parent.isValid()) {
         return 0;
     }
-    return m_engine->searchPresets().count();
+    return m_engine->d->searchPresets.count();
 }
 
 void SearchPresetModel::loadSearch(const QModelIndex &index)
@@ -109,8 +116,8 @@ void SearchPresetModel::loadSearch(const QModelIndex &index)
         qCWarning(KNEWSTUFFQUICK) << "index SearchPresetModel::loadSearch invalid" << index;
         return;
     }
-    const KNSCore::Provider::SearchPreset preset = m_engine->searchPresets().at(index.row());
-    m_engine->search(preset.request);
+    const auto preset = m_engine->d->searchPresets.at(index.row());
+    m_engine->search(preset.request());
 }
 
 #include "moc_searchpresetmodel.cpp"
